/*
 * 미세먼지와 온습도를 측정
 * 
 * DHT_Sensor_library_master, Arduino-LiquidCrystal-I2C-library-mast 라이브러리 설치
 * 
 */

#include <LiquidCrystal_I2C.h>
#include "DHT.h"

#define DHTPIN 7        //온습도 센서는 7번핀에 연결
#define DHTTYPE DHT11   //온습도 센서는 DHT11

int measurePin = A0;  //미세먼지센서는 A0에 연결
int ledPower = 8;     //미세먼지센서 LED는 8번핀에 연결 

int samplingTime = 280;
int deltaTime = 40;
int sleepTime = 9680;
float voMeasured = 0;
float calcVoltage = 0;
float dustDensity = 0;

DHT dht(DHTPIN, DHTTYPE);

LiquidCrystal_I2C lcd(0x27, 16, 2);  

void setup(){
  Serial.begin(9600);
  lcd.begin();
  lcd.backlight();
  lcd.clear();
  pinMode(ledPower,OUTPUT);
  dht.begin();
}

void loop(){
  //미세먼지 농도 측정
  digitalWrite(ledPower,LOW); // power on the LED
  delayMicroseconds(samplingTime);
  voMeasured = analogRead(measurePin); // read the dust value
  delayMicroseconds(deltaTime);
  digitalWrite(ledPower,HIGH); // turn the LED off
  delayMicroseconds(sleepTime);
  calcVoltage = voMeasured * (5.0 / 1024.0);

  dustDensity = 0.17 * calcVoltage;
  int dus = dustDensity * 1000;

  //온습도 측정
  float h = dht.readHumidity();
  float t = dht.readTemperature();
  
  
  //습도 출력
  Serial.print(F("Humidity: "));
  Serial.print(h);
  Serial.println(F("%")); 
  
  lcd.setCursor(0, 0);
  lcd.print("H:");
  lcd.print(h);
  lcd.print("% ");

  //온도 출력
  Serial.print(F("Temperature: "));
  Serial.print(t);
  Serial.println(F("°C"));
  lcd.print("T:");
  lcd.print(t);
  lcd.print("C");

  //미세먼지 출력
  Serial.print("Dust Sensor Voltage: ");
  Serial.print(dustDensity);
  Serial.println("V");
  Serial.print("Dust Value: ");
  Serial.print(dus); // unit: mg/m3
  Serial.println("ug");  
  lcd.setCursor(0, 1);
  lcd.print("Dust: ");
  lcd.print(dus);
  lcd.print("ug"); 
    
  //RGB LED에 미세먼지 상태출력
  if (dus < 70) {                 // 좋음
    analogWrite(9, 255);
    analogWrite(10, 0);
  }
  if (dus > 70 & dus < 100) {    // 나쁨
    analogWrite(9, 100);
    analogWrite(10, 100);
  }
  if (dus > 100) {                // 매우나쁨
    analogWrite(9, 0);
    analogWrite(10, 255);
  }
  
  delay(2000);
}
